/*
	Dreamcast VMU minigame uploader
	
	Uploads a VMS rom to the vmu in controller one
	
	MAKE SURE that nd.hdroff = 1; in vmufs_write (vmufs.c, ~line 750) 
	and recompile KOS for this to work
	
	Tiny Tetris game by Marcus Comstedt 
	http://mc.pp.se/
*/
//VMS file location 
#define ROM_FILE_PATH "/pc/tetris.vms"
//VMS File name
#define ROM_NAME "TINY TETRIS"

#include <kos.h>

long int getFileSize(FILE* fp){
	fseek(fp,0L,SEEK_END);
	long int sz = ftell(fp);
	fseek(fp,0L,SEEK_SET);
	return sz;
}


int main(int argc,char** argv){
	const char* filePath = ROM_FILE_PATH;
	
	maple_device_t* vDev = maple_enum_dev(0,1);	//vmu in first controller
	if(vDev == 0){
		printf("Error: Couldn't find VMU in slot 1 of first controller.\n");
		return 0;
	}
	
	
	FILE* fp = fopen(filePath,"rb");
	
	if(fp == NULL){
		printf("Error: Failed to open %s\n",filePath);
		return 0;
	}
	
	long int fileSize = getFileSize(fp);
	
	printf("VMS ROM Size: %d\n",(int)fileSize);
	
	void* vmsFile = malloc(sizeof(uint8)*fileSize);
	
	fread(vmsFile,sizeof(uint8),fileSize,fp);
	fclose(fp);
	
	char vmuFileName[12];
	strncpy(vmuFileName,ROM_NAME,12);
	printf("Writing ROM...\n");
	if(vmufs_write(vDev,vmuFileName,vmsFile,fileSize,VMUFS_VMUGAME)){
		printf("VMU: Error, failed to write game to VMU!\n");
	}
	printf("Completed.\n");
	free(vmsFile);
	return 0;
}

